@@ -1147,6 +1147,8 @@ class DataFrameIOLayer(Blockwise):
     io_func : callable
         A callable function that takes in a single tuple
         of arguments, and outputs a DataFrame partition.
+        Column projection will be supported for functions
+        that satisfy the ``DataFrameIOFunction`` protocol.
     label : str (optional)
         String to use as a prefix in the place-holder collection
         name. If nothing is specified (default), "subset-" will
@@ -1177,7 +1179,7 @@ class DataFrameIOLayer(Blockwise):
         annotations=None,
     ):
         self.name = name
-        self.columns = columns
+        self._columns = columns
         self.inputs = inputs
         self.io_func = io_func
         self.label = label
@@ -1205,22 +1207,32 @@ class DataFrameIOLayer(Blockwise):
             annotations=annotations,
         )
 
+    @property
+    def columns(self):
+        """Current column projection for this layer"""
+        return self._columns
+
     def project_columns(self, columns):
         """Produce a column projection for this IO layer.
         Given a list of required output columns, this method
         returns the projected layer.
         """
-        if columns and (self.columns is None or columns < set(self.columns)):
+        from dask.dataframe.io.utils import DataFrameIOFunction
 
-            # Apply column projection in IO function
-            try:
-                io_func = self.io_func.project_columns(list(columns))
-            except AttributeError:
+        columns = list(columns)
+
+        if self.columns is None or set(self.columns).issuperset(columns):
+
+            # Apply column projection in IO function.
+            # Must satisfy `DataFrameIOFunction` protocol
+            if isinstance(self.io_func, DataFrameIOFunction):
+                io_func = self.io_func.project_columns(columns)
+            else:
                 io_func = self.io_func
 
             layer = DataFrameIOLayer(
-                (self.label or "subset-") + tokenize(self.name, columns),
-                list(columns),
+                (self.label or "subset") + "-" + tokenize(self.name, columns),
+                columns,
                 self.inputs,
                 io_func,
                 label=self.label,
