@@ -491,6 +491,28 @@ def test_blockwise_different_optimization(c):
     np.testing.assert_equal(y_value, expected)
 
 
+def test_blockwise_cull_allows_numpy_dtype_keys(c):
+    # Regression test for https://github.com/dask/dask/issues/9072
+    da = pytest.importorskip("dask.array")
+    np = pytest.importorskip("numpy")
+
+    # Create a multi-block array.
+    x = da.ones((100, 100), chunks=(10, 10))
+
+    # Make a layer that pulls a block out of the array, but
+    # refers to that block using a numpy.int64 for the key rather
+    # than a python int.
+    name = next(iter(x.dask.layers))
+    block = {("block", 0, 0): (name, np.int64(0), np.int64(1))}
+    dsk = HighLevelGraph.from_collections("block", block, [x])
+    arr = da.Array(dsk, "block", ((10,), (10,)), dtype=x.dtype)
+
+    # Stick with high-level optimizations to force serialization of
+    # the blockwise layer.
+    with dask.config.set({"optimization.fuse.active": False}):
+        da.assert_eq(np.ones((10, 10)), arr, scheduler=c)
+
+
 @gen_cluster(client=True)
 async def test_combo_of_layer_types(c, s, a, b):
     """Check pack/unpack of a HLG that has every type of Layers!"""
@@ -775,3 +797,36 @@ def test_set_index_no_resursion_error(c):
         ddf.compute()
     except RecursionError:
         pytest.fail("dd.set_index triggered a recursion error")
+
+
+@pytest.mark.xfail(reason="https://github.com/dask/dask/issues/8991", strict=True)
+@gen_cluster(client=True)
+async def test_gh_8991(c, s, a, b):
+    # Test illustrating something amiss with HighLevelGraph.key_dependencies.
+    # The intention is for this to be a cache, so if we clear it, things
+    # should still work.
+
+    # This is a bad test, and we should rethink/remove it as soon as the issue is
+    # resolved whether, it's fixing the underlying problem or removing
+    # HighLevelGraph.key_dependencies alltogether.
+    datasets = pytest.importorskip("dask.datasets")
+    result = datasets.timeseries().shuffle("x").to_orc("tmp", compute=False)
+
+    # Create a dsk and mock sending it to the scheduler.
+    dsk_opt = result.__dask_optimize__(result.dask, result.key)
+    unpacked = HighLevelGraph.__dask_distributed_unpack__(
+        dsk_opt.__dask_distributed_pack__(c, result.key)
+    )
+    deps = unpacked["deps"]
+
+    # Create a version of the dsk without the key_dependencies and mock sending it to
+    # the scheduler as well.
+    dsk_opt_nokeys = dsk_opt.copy()
+    dsk_opt_nokeys.key_dependencies.clear()
+    unpacked_nokeys = HighLevelGraph.__dask_distributed_unpack__(
+        dsk_opt_nokeys.__dask_distributed_pack__(c, result.key)
+    )
+    deps_nokeys = unpacked_nokeys["deps"]
+
+    # The recalculated dependencies should still be the same!
+    assert deps == deps_nokeys
